==> libreoffice-fresh-sdk-25.2.2-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.js <==
var interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration =
[
    [ "XUIConfiguration", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#abec5cc3bee5872b28b2a24c71f43e7b3", null ],
    [ "XUIConfigurationPersistence", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#ad1b90c5de347fb7e4bed4c4f151d9491", null ],
    [ "XUIConfigurationStorage", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a6523c81be4a9f7ce9b275a574d1e0d3b", null ],
    [ "getAllKeyEvents", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#abd29885836333724566ce3e3daae0057", null ],
    [ "getCommandByKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a92d11c4f5d7c7779d49a41c2860f7454", null ],
    [ "getKeyEventsByCommand", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a40942ee6718509fda52acac53da7beef", null ],
    [ "getPreferredKeyEventsForCommandList", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a0c4340bce7cf3129ecf928276af1252f", null ],
    [ "removeCommandFromAllKeyEvents", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a2caa255ddc96b22e8d83d6944555d42d", null ],
    [ "removeKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#aac7e919dfe534c1fc45ea3c8ee79068c", null ],
    [ "setKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a29d76ebbbf97de323d39df484b8f0745", null ]
];

==> libreoffice-fresh-sdk-25.8.3-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.js <==
var interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration =
[
    [ "com::sun::star::ui::XUIConfiguration", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#abec5cc3bee5872b28b2a24c71f43e7b3", null ],
    [ "com::sun::star::ui::XUIConfigurationPersistence", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#ad1b90c5de347fb7e4bed4c4f151d9491", null ],
    [ "com::sun::star::ui::XUIConfigurationStorage", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a6523c81be4a9f7ce9b275a574d1e0d3b", null ],
    [ "getAllKeyEvents", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#abd29885836333724566ce3e3daae0057", null ],
    [ "getCommandByKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a92d11c4f5d7c7779d49a41c2860f7454", null ],
    [ "getKeyEventsByCommand", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a40942ee6718509fda52acac53da7beef", null ],
    [ "getPreferredKeyEventsForCommandList", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a0c4340bce7cf3129ecf928276af1252f", null ],
    [ "removeCommandFromAllKeyEvents", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a2caa255ddc96b22e8d83d6944555d42d", null ],
    [ "removeKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#aac7e919dfe534c1fc45ea3c8ee79068c", null ],
    [ "setKeyEvent", "interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html#a29d76ebbbf97de323d39df484b8f0745", null ]
];
